import{d as s,a6 as m,z as n,W as e,c as l,g as c,f as u,b as f}from"./index-2e87fa03.js";import{I as h}from"./ItemsListing-efdefe10.js";import"./VCheckbox-386509eb.js";import"./eventbus-0b29a02c.js";import"./VListItem-89fd7b1a.js";import"./VCheckboxBtn-95584b13.js";import"./VList-a4b75488.js";import"./VCardText-064374a3.js";import"./VCard-c125380f.js";import"./VMenu-148e092d.js";import"./_plugin-vue_export-helper-c27b6911.js";import"./ListItem-db7cb046.js";import"./Button-74c30473.js";import"./VSpacer-f5f551d9.js";/* empty css              */import"./PanelviewItemCompact-a679900d.js";import"./VAlert-d83244d0.js";import"./Container-a429dbf0.js";import"./Toolbar-0e15c31f.js";import"./VToolbar-00d7489e.js";import"./VTextField-6302d32d.js";import"./VInfiniteScroll-72c5f022.js";import"./layout-61f409b8.js";import"./VVirtualScroll-9a54f195.js";const J=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:r}=m(),a=n(()=>!t.path||t.path=="root"?r("browse"):e("bp6")?r("browse")+" | "+t.path:e("bp3")?t.path:r("browse")),p=async function(o){return await f.browse(o.offset,o.limit,t.path)};return(o,d)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-paged-data":p,"sort-keys":["original","name","name_desc"],title:a.value,path:o.path,"allow-key-hooks":!0,icon:"mdi-folder-outline","no-server-side-sorting":!0},null,8,["title","path"])]))}});export{J as default};
